@@ -1,11 +1,11 @@
 from enum import Enum
-from typing import Union
 from urllib.parse import quote_plus
 
 from pymongo import MongoClient
 from pymongo.errors import ServerSelectionTimeoutError, OperationFailure
 
 MAX_SEV_SEL_DELAY = 5
+DEF_MONGODB_PORT = 27017
 
 
 class Mode(Enum):
@@ -51,6 +51,8 @@ def uri_connect(host: str = 'localhost', port: int = 27017, replicaset: str = No
         uri += f'{user}' if user else ''
         uri += f':{password}' if password else ''
     host = host if host.endswith('/') else f'{host}/'
+    port = port if port else DEF_MONGODB_PORT
+    host = host[:-1] + f':{port}' + '/' if port else host
     uri += f'@{host}' if user and mode not in [Mode.MONGODB_AWS] else host
     if mode and mode.value:
         uri += f'?authMechanism={mode.value}' + \
@@ -61,12 +63,12 @@ def uri_connect(host: str = 'localhost', port: int = 27017, replicaset: str = No
 
     if cert_key_file:
         if replicaset:
-            return MongoClient(uri, port, replicaset=replicaset, tls=True, tlsCertificateKeyFile=cert_key_file,
+            return MongoClient(uri, replicaset=replicaset, tls=True, tlsCertificateKeyFile=cert_key_file,
                                tlsCAFile=ca_file, serverSelectionTimeoutMS=MAX_SEV_SEL_DELAY)
-        return MongoClient(host, port, serverSelectionTimeoutMS=MAX_SEV_SEL_DELAY)
+        return MongoClient(uri, serverSelectionTimeoutMS=MAX_SEV_SEL_DELAY)
     if replicaset:
-        return MongoClient(uri, port, replicaset=replicaset, serverSelectionTimeoutMS=MAX_SEV_SEL_DELAY)
-    return MongoClient(host, port, serverSelectionTimeoutMS=MAX_SEV_SEL_DELAY)
+        return MongoClient(uri, replicaset=replicaset, serverSelectionTimeoutMS=MAX_SEV_SEL_DELAY)
+    return MongoClient(uri, serverSelectionTimeoutMS=MAX_SEV_SEL_DELAY)
 
 
 def auth_connect(host: str = 'localhost', port: int = 27017, replicaset: str = None, database: str = None,
